Index: /issm/trunk-jpl/src/c/classes/Node.cpp
===================================================================
--- /issm/trunk-jpl/src/c/classes/Node.cpp	(revision 21481)
+++ /issm/trunk-jpl/src/c/classes/Node.cpp	(revision 21482)
@@ -458,6 +458,7 @@
 
 	/*Put dof for this node into the f set (ie, this dof will NOT be constrained 
 	 * to a fixed value during computations. */
 	_assert_(dof<this->indexing.gsize);
+	_assert_(this->indexing.active);
 
 	if(this->indexing.f_set[dof] == 0){
@@ -458,6 +458,7 @@
 
 	/*Put dof for this node into the f set (ie, this dof will NOT be constrained 
-	 * to a fixed value during computations. */
+	 * to a fixed value during computations. Only do this for active nodes. */
 	_assert_(dof<this->indexing.gsize);
